#
# spec file for package python-responses
#
# Copyright (c) 2021 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-responses
Version:        0.15.0
Release:        bp153.2.3.1
Summary:        A utility library for mocking out the `requests` Python library
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/getsentry/responses
Source:         https://files.pythonhosted.org/packages/source/r/responses/responses-%{version}.tar.gz
# test requirements
BuildRequires:  %{python_module cookies}
BuildRequires:  %{python_module mock}
BuildRequires:  %{python_module pytest-localserver}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.0}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module six}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.0
Requires:       python-six
Suggests:       python-pytest
BuildArch:      noarch
%ifpython2
Requires:       python2-cookies
Requires:       python2-mock
%endif
%python_subpackages

%description
A utility library for mocking out the requests Python library.
Check https://github.com/getsentry/responses for more information
about the library.

%prep
%setup -q -n responses-%{version}

%build
export LANG="en_US.UTF8"
export PYTHONIOENCODING="utf_8"
%python_build

%install
export LANG="en_US.UTF8"
export PYTHONIOENCODING="utf_8"
%python_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%doc CHANGES README.rst
%license LICENSE
%{python_sitelib}/*

%changelog
* Sat Oct 30 2021 Dirk Müller <dmueller@suse.com>
- update to 0.15.0:
  * Added `responses.PassthroughResponse` and
    `reponses.BaseResponse.passthrough`. These features make building passthrough
    responses more compatible with dynamcially generated response objects.
  * Removed the unused ``_is_redirect()`` function from responses internals.
  * Added `responses.matchers.request_kwargs_matcher`. This matcher allows you
    to match additional request arguments like `stream`.
  * Added `responses.matchers.multipart_matcher`. This matcher allows you
    to match request body and headers for ``multipart/form-data`` data
  * Added `responses.matchers.query_string_matcher`. This matcher allows you
    to match request query string, similar to `responses.matchers.query_param_matcher`.
  * Added `responses.matchers.header_matcher()`. This matcher allows you to match
    request headers. By default only headers supplied to `header_matcher()` are checked.
    You can make header matching exhaustive by passing `strict_match=True` to `header_matcher()`.
  * Changed all matchers output message in case of mismatch. Now message is aligned
    between Python2 and Python3 versions
  * Deprecate ``stream`` argument in ``Response`` and ``CallbackResponse``
  * Added Python 3.10 support
* Tue Oct 26 2021 Dirk Müller <dmueller@suse.com>
- update to 0.14.0:
  * Added `responses.matchers`.
  * Moved `responses.json_params_matcher` to `responses.matchers.json_param_matcher`
  * Moved `responses.urlencoded_params_matcher` to
  `responses.matchers.urlencoded_param_matcher`
  * Added `responses.query_params_matcher`. This matcher allows you to match
    query strings with a dictionary.
  * Added `auto_calculate_content_length` option to `responses.add()`. When
    enabled, this option will generate a `Content-Length` header
    based on the number of bytes in the response body.
  * Improve typing support
  * Use URLs with normalized hostnames when comparing URLs.
* Tue May 18 2021 Dirk Müller <dmueller@suse.com>
- update to 0.13.3:
  * Switch from Travis to GHA for deployment.
  * Fixed incorrect type stubs for `add_callback`
  * Fixed packages not containing type stubs.
  * `responses.upsert()` was added. This method will `add()` a response if one
    has not already been registered for a URL, or `replace()` an existing
    response.
  * `responses.registered()` was added. The method allows you to get a list of
    the currently registered responses. This formalizes the previously private
    `responses.mock._matches` method.
  * A more useful `__repr__` has been added to `Response`.
  * Error messages have been improved.
* Mon Mar  8 2021 Dirk Müller <dmueller@suse.com>
- update to 0.12.1:
  * `responses.urlencoded_params_matcher` and `responses.json_params_matcher` now
    accept None to match empty requests.
  * Fixed imports to work with new `urllib3` versions.
  * `request.params` now allows parameters to have multiple values for the same key.
  * Improved ConnectionError messages.
  - Remove support for Python 3.4.
  - Added the `match` parameter to `add()`.
  - Added `responses.urlencoded_params_matcher()` and `responses.json_params_matcher()`.
  - Add a requirements pin to urllib3. This helps prevent broken install states where
    cookie usage fails.
  - Added `assert_call_count` to improve ergonomics around ensuring a mock was called.
  - Fix incorrect handling of paths with query strings.
  - Add Python 3.9 support to CI matrix.
* Mon Jun  8 2020 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.10.14
  * Improved handling of unicode bodies
  * Streamlined querysting matching code
* Wed May 27 2020 Andreas Hasenkopf <ahasenkopf@suse.com>
- Set encodings to UTF-8 to avoid UnicodeDecodeError
* Thu Mar 19 2020 pgajdos@suse.com
- version update to 0.10.12
  - Fixed incorrect content-type in `add_callback()` when headers are provided as a list of tuples.
  - Fixed invalid README formatted.
  - Fixed string formatting in error message.
  - Added Python 3.8 support
  - Remove Python 3.4 from test suite matrix.
  - The `response.request` object now has a `params` attribute that contains the query string parameters from the request that was captured.
  - `add_passthru` now supports `re` pattern objects to match URLs.
  - ConnectionErrors raised by responses now include more details on the request that was attempted and the mocks registered.
  - Fixed regression with `add_callback()` and content-type header.
  - Fixed implicit dependency on urllib3>1.23.0
  - Fixed cookie parsing and enabled multiple cookies to be set by using a list of
    tuple values.
  - Added pypi badges to README.
  - Fixed formatting issues in README.
  - Quoted cookie values are returned correctly now.
  - Improved compatibility for pytest 5
  - Module level method names are no longer generated dynamically improving IDE navigation.
* Thu Oct 17 2019 Dirk Mueller <dmueller@suse.com>
- switch to pytest4 actually not pytest3
* Thu Jul 18 2019 Tomáš Chvátal <tchvatal@suse.com>
- Hardcode pytest4 for testing as pytest5 fails for now
* Tue May 14 2019 Ondřej Súkup <mimi.vx@gmail.com>
- update to 0.10.6
- drop tidy-py_modules.patch
- use %%pytest macro
  * ConnectionError's raised by responses now indicate which request
    path/method failed to match a mock.
* Sun Feb 10 2019 John Vandenberg <jayvdb@gmail.com>
- Activate tests
- Remove test_responses.py from package:
  * tidy-py_modules.patch
- Remove unnecessary build dependencies
- Remove inappropriate Suggests
- Add missing changelog entry for v0.10.5
* Tue Feb  5 2019 John Paul Adrian Glaubitz <adrian.glaubitz@suse.com>
- Update to 0.10.5
  + Fix callback exception mocking.
  + Improve test coverage
  + Improve build configuration.
- from version 0.10.4
  + Fixed generated wrapper when using `@responses.activate` in Python 3.6+
    when decorated functions use parameter and/or return annotations.
- from version 0.10.3
  + Fixed deprecation warnings in python 3.7 for inspect module usage.
- from version 0.10.2
  + Fixed build setup to use undeprecated `pytest` bin stub.
  + Updated `tox` configuration.
  + Added example of using responses with `pytest.fixture`.
  + Removed dependency on `biscuits` in py3. Instead `http.cookies` is being used.
- from version 0.10.1
  + Packaging fix to distribute wheel (#219).
- from version 0.10.0
  + Fix passing through extra settings (#207).
  + Fix collections.abc warning on Python 3.7 (#215).
  + Use 'biscuits' library instead of 'cookies' on Python 3.4+ (#218).
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Mon Jul  9 2018 sean.marlow@suse.com
- Update to 0.9.0
  + Support for Python 3.7
  + Support streaming responses for BaseResponse
  + Support custom patch targets for mock
  + Fix unicode support for passthru urls
  + Fix support for unicode in domain names and tlds
* Fri Mar  9 2018 mimi.vx@gmail.com
- Fix python2 requires
* Fri Jan 12 2018 mimi.vx@gmail.com
- update to 0.8.1
  * Added the ability to passthru real requests via ``add_passthru()``
  and ``passthru_prefixes`` configurations.
  * Responses will now be rotated until the final match is hit, and
  then persist using that response (GH-171).
  * Fixed call counting with exceptions (GH-163).
  * Fixed behavior with arbitrary status codes (GH-164).
  * Fixed handling of multiple responses with the same match (GH-165).
  * Fixed default path behavior with ``match_querystring`` (GH-166).
  * Restored ``adding_headers`` compatibility (GH-160).
  * Allow empty list/dict as json object (GH-100).
  * Added `response_callback` (GH-151).
  * Added ``Response`` interfaces (GH-155).
  * Fixed unicode characters in querystring (GH-153).
  * Added support for streaming IO buffers (GH-154).
  * Added support for empty (unset) Content-Type (GH-139).
  * Added reason to mocked responses (GH-132).
  * ``yapf`` autoformatting now enforced on codebase.
* Mon Apr 10 2017 alarrosa@suse.com
- Update for singlespec
* Thu Jan 19 2017 alarrosa@suse.com
- Initial release
